@@ -27,13 +27,9 @@
 #include <KLocalizedString>
 
 #include <KIO/FavIconRequestJob>
-#include <kio/job.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KParts/BrowserExtension>
-#else
 #include <KParts/NavigationExtension>
-#endif
 #include <KParts/PartLoader>
+#include <kio/job.h>
 
 FavIconUpdater::FavIconUpdater(QObject *parent)
     : QObject(parent)
@@ -75,29 +71,21 @@ void FavIconUpdater::downloadIconUsingWebBrowser(const KBookmark &bk, const QStr
     webupdate = true;
 
     if (!m_part) {
-        QString partLoadingError;
-        KParts::ReadOnlyPart *part =
-            KParts::PartLoader::createPartInstanceForMimeType<KParts::ReadOnlyPart>(QStringLiteral("text/html"), nullptr, this, &partLoadingError);
-        if (!part) {
-            Q_EMIT done(false, i18n("%1; no HTML component found (%2)", currentError, partLoadingError));
+        auto partResult = KParts::PartLoader::instantiatePartForMimeType<KParts::ReadOnlyPart>(QStringLiteral("text/html"), nullptr, this);
+        if (!partResult) {
+            Q_EMIT done(false, i18n("%1; no HTML component found (%2)", currentError, partResult.errorString));
             return;
         }
 
+        auto part = partResult.plugin;
         part->setProperty("pluginsEnabled", QVariant(false));
         part->setProperty("javaScriptEnabled", QVariant(false));
         part->setProperty("javaEnabled", QVariant(false));
         part->setProperty("autoloadImages", QVariant(false));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        KParts::BrowserExtension *ext = KParts::BrowserExtension::childObject(part);
-        Q_ASSERT(ext);
-
-        connect(ext, &KParts::BrowserExtension::setIconUrl, this, &FavIconUpdater::setIconUrl);
-#else
         KParts::NavigationExtension *ext = KParts::NavigationExtension::childObject(part);
         Q_ASSERT(ext);
 
         connect(ext, &KParts::NavigationExtension::setIconUrl, this, &FavIconUpdater::setIconUrl);
-#endif
         m_part = part;
     }
 
