@@ -50,7 +50,7 @@ public:
     }
     KBookmarkManager *mgr() const
     {
-        return m_mgr;
+        return m_mgr.get();
     }
     QString path() const;
 
@@ -68,9 +68,12 @@ public:
     static QString makeTimeStr(const QString &);
     static QString makeTimeStr(int);
 
+Q_SIGNALS:
+    void error(const QString &errorMessage);
+
 private:
     GlobalBookmarkManager();
-    KBookmarkManager *m_mgr;
+    std::unique_ptr<KBookmarkManager> m_mgr;
     KBookmarkModel *m_model;
     static GlobalBookmarkManager *s_mgr;
 };
